# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-04-28 08:50
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_cms', '0003_auto_20170418_1515'),
    ]

    operations = [
        migrations.AddField(
            model_name='sliderelementtexten',
            name='name_file',
            field=models.CharField(blank=True, max_length=254, null=True, verbose_name='Name'),
        ),
        migrations.AddField(
            model_name='sliderelementtextes',
            name='name_file',
            field=models.CharField(blank=True, max_length=254, null=True, verbose_name='Name'),
        ),
        migrations.AddField(
            model_name='staticheaderelementtexten',
            name='name_file',
            field=models.CharField(blank=True, max_length=254, null=True, verbose_name='Name'),
        ),
        migrations.AddField(
            model_name='staticheaderelementtextes',
            name='name_file',
            field=models.CharField(blank=True, max_length=254, null=True, verbose_name='Name'),
        ),
    ]
