# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-04-18 15:15
from __future__ import unicode_literals

import django.core.validators
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_cms', '0002_auto_20170327_1021'),
    ]

    operations = [
        migrations.AlterField(
            model_name='staticheader',
            name='num_elements',
            field=models.IntegerField(validators=[django.core.validators.MaxValueValidator(4), django.core.validators.MinValueValidator(1)], verbose_name='Number of columns'),
        ),
    ]
