# -*- coding: utf-8 -*-
# Generated by Django 1.10.8 on 2017-11-23 09:19
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_cms', '0007_auto_20171115_1546'),
    ]

    operations = [
        migrations.AlterField(
            model_name='sliderelement',
            name='show_title',
            field=models.BooleanField(default=False, verbose_name='Show title'),
        ),
        migrations.AlterField(
            model_name='staticheaderelement',
            name='show_title',
            field=models.BooleanField(default=False, verbose_name='Show title'),
        ),
    ]
