# -*- coding: utf-8 -*-
# Generated by Django 1.10.5 on 2017-03-27 10:21
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_cms', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='slider',
            name='identifier',
            field=models.CharField(blank=True, max_length=200, null=True, unique=True, verbose_name='Identifier'),
        ),
        migrations.AlterField(
            model_name='staticheader',
            name='identifier',
            field=models.CharField(blank=True, max_length=200, null=True, unique=True, verbose_name='Identifier'),
        ),
    ]
